/*!
 * @file ovinotificationmessage.h
 * @brief OviNotificationMessage is received from application or a service. OviNotificationMessage is
 *            received in OviNotificationSession::received() signal.
 *
 * This file is part of Notifications API
 * <p>
 * @copyright  Copyright (C) 2010-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *             Contact:  notifications.support@nokia.com
 *             This software, including documentation, is protected by copyright controlled by Nokia Corporation.
 *             All rights reserved. You may use this file only in accordance with the Nokia Developer Software
 *             Agreement version 2.0 and accompanying Ovi any additional terms. This material also contains
 *             confidential information which may not be disclosed to others without the prior written consent of Nokia.
 *
 * @license Nokia Developer Software Agreement version 2.0 and accompanying Ovi any additional terms
 * </p>
 */


#ifndef OVINOTIFICATIONMESSAGE_H_
#define OVINOTIFICATIONMESSAGE_H_

#include <QObject>
#include <QVariant>
#include <QString>

// Forward declarations
class OviNotificationResponseHandler;
class OviNotificationMessagePrivate;
class OviNotificationPayload;

class OviNotificationMessage : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString from READ from)
    Q_PROPERTY(QString senderInformation READ senderInformation)
    Q_PROPERTY(QString timestamp READ timestamp)
    Q_PROPERTY(QObject* payload READ payload)

public:

    OviNotificationMessage();
    ~OviNotificationMessage();

public slots:

    /*!
     * Returns sender's JID.
     *
     * @return The sender's JID.
     */
    virtual QString from() const;

    /*!
     * Returns sender application's id.
     *
     * @return Sender application id.
     */
    virtual QString senderInformation() const;

    /*!
     * Returns message publication time in following format:
     * "2009-10-05T13:20:19Z"
     *
     * @return Timestamp of the message in string.
     */
    virtual QString timestamp() const;

     /*!
     * Returns OviNotificationPayload object.
     *
     * @return QObject payload object.
     */
    virtual QObject* payload() const;


private:

    OviNotificationMessagePrivate *impl;

    // Friend classes
    friend class OviNotificationResponseHandler;
};

#endif /* OVINOTIFICATIONMESSAGE_H_ */
