/*!
 * @file ovinotificationpayload.h
 * @brief OviNotificationPayload is the notification payload that is received from the service.
 *
 * This file is part of Notifications API
 * <p>
 * @copyright  Copyright (C) 2010-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *             Contact:  notifications.support@nokia.com
 *             This software, including documentation, is protected by copyright controlled by Nokia Corporation.
 *             All rights reserved. You may use this file only in accordance with the Nokia Developer Software
 *             Agreement version 2.0 and accompanying Ovi any additional terms. This material also contains
 *             confidential information which may not be disclosed to others without the prior written consent of Nokia.
 *
 * @license Nokia Developer Software Agreement version 2.0 and accompanying Ovi any additional terms
 * </p>
 */


#ifndef OVINOTIFICATIONPAYLOAD_H_
#define OVINOTIFICATIONPAYLOAD_H_

#include <QObject>
#include <QVariant>
#include <QString>

// Forward declarations
class OviNotificationPayloadPrivate;

class OviNotificationPayload : public QObject
{
    Q_OBJECT
	Q_PROPERTY(QString dataString READ dataString)
	Q_PROPERTY(QString type READ type)
	Q_PROPERTY(QString encoding READ encoding)
	Q_PROPERTY(QByteArray data READ data)

public:

    OviNotificationPayload();
    ~OviNotificationPayload();

public slots:

    /*!
     * Returns the payload data as a string.
     *
     * @return Payload data string
     */
    virtual QString dataString() const;

    /*!
     * Returns the content type of the data.
     * It is recommended to use IANA registered content types.
     *
     * @return Content type string
     */
    virtual QString type() const;

    /*!
     * Returns the encoding type of the data.
     * Default encoding is base64. If the service prefers to use
     * some other coding the value will carry identifier for the encoding used.
     * Empty value means no encoding used.
     *
     * @return Encoding type string
     */
    virtual QString encoding() const;

    /*!
     * Returns the payload data as a bytearray.
     *
     * @return Payload data
     */
    virtual QByteArray data() const;


private:

    OviNotificationPayloadPrivate *impl;

    // Friend classes
    friend class OviNotificationResponseHandler;
};

#endif /* OVINOTIFICATIONMESSAGE_H_ */
